This is the mail archive of the gdb-patches@sourceware.org mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

Re: [PATCH] Remove same-pc breakpoint notification for internal BPs


Hello,

here is an updated version of the patch, which uses `user_breakpoint_p'


thanks,

Kevin (still waiting for copyright papers)

--

2011-04-27  Kevin Pouget <kevin.pouget@st.com>
       * breakpoint.c (describe_other_breakpoints): Do not write 'duplicate'
       note if the breakpoint is internal.

diff --git a/gdb/breakpoint.c b/gdb/breakpoint.c
index 2352191..3474caf 100644
--- a/gdb/breakpoint.c
+++ b/gdb/breakpoint.c
@@ -5397,7 +5397,7 @@ breakpoint_has_pc (struct breakpoint *b,
   return 0;
 }

 /* Print a message describing any breakpoints set at PC.  This
    concerns with logical breakpoints, so we match program spaces, not
    address spaces.  */

@@ -5410,7 +5410,8 @@ describe_other_breakpoints (struct gdbarch *gdbarch,
   struct breakpoint *b;

   ALL_BREAKPOINTS (b)
-    others += breakpoint_has_pc (b, pspace, pc, section);
+    others += (breakpoint_has_pc (b, pspace, pc, section)
+               && user_breakpoint_p (b));
   if (others > 0)
     {
       if (others == 1)
@@ -5418,7 +5419,7 @@ describe_other_breakpoints (struct gdbarch *gdbarch,
       else /* if (others == ???) */
 	printf_filtered (_("Note: breakpoints "));
       ALL_BREAKPOINTS (b)
-	if (breakpoint_has_pc (b, pspace, pc, section))
+	if (breakpoint_has_pc (b, pspace, pc, section) && user_breakpoint_p (b))
 	  {
 	    others--;
 	    printf_filtered ("%d", b->number);
@@ -5397,7 +5397,7 @@ breakpoint_has_pc (struct breakpoint *b,
 }

-/* Print a message describing any breakpoints set at PC.  This
+/* Print a message describing any user-breakpoints set at PC.  This
    concerns with logical breakpoints, so we match program spaces, not
    address spaces.  */
--


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]